@@ -4,14 +4,15 @@
 """
 Utility module to group commonly used types for type annotation.
 """
-from collections.abc import (
-    Callable,
-    Generator,
-    Iterable,
-    Sequence,
-    Mapping,
-)
 from typing import (
     Any,
+    Callable,
+    Dict,
+    Generator,
+    Iterable,
+    List,
+    Mapping,
+    Sequence,
+    Tuple,
     Union,
 )
